operations

package
v0.0.0-...-36f1224 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2024 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ServiceOrderingV42API

type ServiceOrderingV42API struct {
	Middleware func(middleware.Builder) http.Handler

	// BasicAuthenticator generates a runtime.Authenticator from the supplied basic auth function.
	// It has a default implementation in the security package, however you can replace it for your particular usage.
	BasicAuthenticator func(security.UserPassAuthentication) runtime.Authenticator

	// APIKeyAuthenticator generates a runtime.Authenticator from the supplied token auth function.
	// It has a default implementation in the security package, however you can replace it for your particular usage.
	APIKeyAuthenticator func(string, string, security.TokenAuthentication) runtime.Authenticator

	// BearerAuthenticator generates a runtime.Authenticator from the supplied bearer token auth function.
	// It has a default implementation in the security package, however you can replace it for your particular usage.
	BearerAuthenticator func(string, security.ScopedTokenAuthentication) runtime.Authenticator

	// JSONConsumer registers a consumer for the following mime types:
	//   - application/json
	JSONConsumer runtime.Consumer

	// JSONProducer registers a producer for the following mime types:
	//   - application/json
	JSONProducer runtime.Producer

	// CancelServiceOrderCreateCancelServiceOrderHandler sets the operation handler for the create cancel service order operation
	CancelServiceOrderCreateCancelServiceOrderHandler cancel_service_order.CreateCancelServiceOrderHandler
	// ServiceOrderCreateServiceOrderHandler sets the operation handler for the create service order operation
	ServiceOrderCreateServiceOrderHandler service_order.CreateServiceOrderHandler
	// ServiceOrderDeleteServiceOrderHandler sets the operation handler for the delete service order operation
	ServiceOrderDeleteServiceOrderHandler service_order.DeleteServiceOrderHandler
	// CancelServiceOrderListCancelServiceOrderHandler sets the operation handler for the list cancel service order operation
	CancelServiceOrderListCancelServiceOrderHandler cancel_service_order.ListCancelServiceOrderHandler
	// ServiceOrderListServiceOrderHandler sets the operation handler for the list service order operation
	ServiceOrderListServiceOrderHandler service_order.ListServiceOrderHandler
	// NotificationListenersClientSideListenToCancelServiceOrderCreateEventHandler sets the operation handler for the listen to cancel service order create event operation
	NotificationListenersClientSideListenToCancelServiceOrderCreateEventHandler notification_listeners_client_side.ListenToCancelServiceOrderCreateEventHandler
	// NotificationListenersClientSideListenToCancelServiceOrderInformationRequiredEventHandler sets the operation handler for the listen to cancel service order information required event operation
	NotificationListenersClientSideListenToCancelServiceOrderInformationRequiredEventHandler notification_listeners_client_side.ListenToCancelServiceOrderInformationRequiredEventHandler
	// NotificationListenersClientSideListenToCancelServiceOrderStateChangeEventHandler sets the operation handler for the listen to cancel service order state change event operation
	NotificationListenersClientSideListenToCancelServiceOrderStateChangeEventHandler notification_listeners_client_side.ListenToCancelServiceOrderStateChangeEventHandler
	// NotificationListenersClientSideListenToServiceOrderAttributeValueChangeEventHandler sets the operation handler for the listen to service order attribute value change event operation
	NotificationListenersClientSideListenToServiceOrderAttributeValueChangeEventHandler notification_listeners_client_side.ListenToServiceOrderAttributeValueChangeEventHandler
	// NotificationListenersClientSideListenToServiceOrderCreateEventHandler sets the operation handler for the listen to service order create event operation
	NotificationListenersClientSideListenToServiceOrderCreateEventHandler notification_listeners_client_side.ListenToServiceOrderCreateEventHandler
	// NotificationListenersClientSideListenToServiceOrderDeleteEventHandler sets the operation handler for the listen to service order delete event operation
	NotificationListenersClientSideListenToServiceOrderDeleteEventHandler notification_listeners_client_side.ListenToServiceOrderDeleteEventHandler
	// NotificationListenersClientSideListenToServiceOrderInformationRequiredEventHandler sets the operation handler for the listen to service order information required event operation
	NotificationListenersClientSideListenToServiceOrderInformationRequiredEventHandler notification_listeners_client_side.ListenToServiceOrderInformationRequiredEventHandler
	// NotificationListenersClientSideListenToServiceOrderJeopardyEventHandler sets the operation handler for the listen to service order jeopardy event operation
	NotificationListenersClientSideListenToServiceOrderJeopardyEventHandler notification_listeners_client_side.ListenToServiceOrderJeopardyEventHandler
	// NotificationListenersClientSideListenToServiceOrderMilestoneEventHandler sets the operation handler for the listen to service order milestone event operation
	NotificationListenersClientSideListenToServiceOrderMilestoneEventHandler notification_listeners_client_side.ListenToServiceOrderMilestoneEventHandler
	// NotificationListenersClientSideListenToServiceOrderStateChangeEventHandler sets the operation handler for the listen to service order state change event operation
	NotificationListenersClientSideListenToServiceOrderStateChangeEventHandler notification_listeners_client_side.ListenToServiceOrderStateChangeEventHandler
	// ServiceOrderPatchServiceOrderHandler sets the operation handler for the patch service order operation
	ServiceOrderPatchServiceOrderHandler service_order.PatchServiceOrderHandler
	// EventsSubscriptionRegisterListenerHandler sets the operation handler for the register listener operation
	EventsSubscriptionRegisterListenerHandler events_subscription.RegisterListenerHandler
	// CancelServiceOrderRetrieveCancelServiceOrderHandler sets the operation handler for the retrieve cancel service order operation
	CancelServiceOrderRetrieveCancelServiceOrderHandler cancel_service_order.RetrieveCancelServiceOrderHandler
	// ServiceOrderRetrieveServiceOrderHandler sets the operation handler for the retrieve service order operation
	ServiceOrderRetrieveServiceOrderHandler service_order.RetrieveServiceOrderHandler
	// EventsSubscriptionUnregisterListenerHandler sets the operation handler for the unregister listener operation
	EventsSubscriptionUnregisterListenerHandler events_subscription.UnregisterListenerHandler

	// ServeError is called when an error is received, there is a default handler
	// but you can set your own with this
	ServeError func(http.ResponseWriter, *http.Request, error)

	// PreServerShutdown is called before the HTTP(S) server is shutdown
	// This allows for custom functions to get executed before the HTTP(S) server stops accepting traffic
	PreServerShutdown func()

	// ServerShutdown is called when the HTTP(S) server is shut down and done
	// handling all active connections and does not accept connections any more
	ServerShutdown func()

	// Custom command line argument groups with their descriptions
	CommandLineOptionsGroups []swag.CommandLineOptionsGroup

	// User defined logger function.
	Logger func(string, ...interface{})
	// contains filtered or unexported fields
}

ServiceOrderingV42API ## TMF API Reference : TMF 641 - Service Ordering Management

Version 4.2.0

The Service Order API provides a standardized mechanism for managing Service Order, a type of order which can be used to place an order between internal Customer Order management system to service order management system or between a service provider and a partner and vice versa.

### Service Order resource A service order will describe a list of service order items. A service order item references an action on an existing or future service. By service we designed Customer Facing Service (CFS) as well as Resource Facing Service (RFS). From a component perspective, a service order should be available - from a Service Orchestration Component (and it could mix CFS and RFS) - from an Infrastructure Control & Management component (and it would have only RFS)

### TMF641 performs the following operations on service order resource : - Retrieval of a service order or a collection of service orders depending on filter criteria - Partial update of a service order (including updating rules) - Creation of a service order (including default values and creation rules) - Deletion of service order (for administration purposes) - Notification of events on Service order

**Cancel Service Order resource**

This resource is used to request a service order cancellation.

**TMF641 provides following operations on Cancel Service Order resource :**

- Retrieval of a cancel service order or a collection of cancel service orders - Creation of a cancel service order - Notification of events on cancel service order.

Copyright © TM Forum 2020. All Rights Reserved

func NewServiceOrderingV42API

func NewServiceOrderingV42API(spec *loads.Document) *ServiceOrderingV42API

NewServiceOrderingV42API creates a new ServiceOrderingV42 instance

func (*ServiceOrderingV42API) AddMiddlewareFor

func (o *ServiceOrderingV42API) AddMiddlewareFor(method, path string, builder middleware.Builder)

AddMiddlewareFor adds a http middleware to existing handler

func (*ServiceOrderingV42API) AuthenticatorsFor

func (o *ServiceOrderingV42API) AuthenticatorsFor(schemes map[string]spec.SecurityScheme) map[string]runtime.Authenticator

AuthenticatorsFor gets the authenticators for the specified security schemes

func (*ServiceOrderingV42API) Authorizer

func (o *ServiceOrderingV42API) Authorizer() runtime.Authorizer

Authorizer returns the registered authorizer

func (*ServiceOrderingV42API) ConsumersFor

func (o *ServiceOrderingV42API) ConsumersFor(mediaTypes []string) map[string]runtime.Consumer

ConsumersFor gets the consumers for the specified media types. MIME type parameters are ignored here.

func (*ServiceOrderingV42API) Context

Context returns the middleware context for the service ordering v42 API

func (*ServiceOrderingV42API) DefaultConsumes

func (o *ServiceOrderingV42API) DefaultConsumes() string

DefaultConsumes returns the default consumes media type

func (*ServiceOrderingV42API) DefaultProduces

func (o *ServiceOrderingV42API) DefaultProduces() string

DefaultProduces returns the default produces media type

func (*ServiceOrderingV42API) Formats

func (o *ServiceOrderingV42API) Formats() strfmt.Registry

Formats returns the registered string formats

func (*ServiceOrderingV42API) HandlerFor

func (o *ServiceOrderingV42API) HandlerFor(method, path string) (http.Handler, bool)

HandlerFor gets a http.Handler for the provided operation method and path

func (*ServiceOrderingV42API) Init

func (o *ServiceOrderingV42API) Init()

Init allows you to just initialize the handler cache, you can then recompose the middleware as you see fit

func (*ServiceOrderingV42API) ProducersFor

func (o *ServiceOrderingV42API) ProducersFor(mediaTypes []string) map[string]runtime.Producer

ProducersFor gets the producers for the specified media types. MIME type parameters are ignored here.

func (*ServiceOrderingV42API) RegisterConsumer

func (o *ServiceOrderingV42API) RegisterConsumer(mediaType string, consumer runtime.Consumer)

RegisterConsumer allows you to add (or override) a consumer for a media type.

func (*ServiceOrderingV42API) RegisterFormat

func (o *ServiceOrderingV42API) RegisterFormat(name string, format strfmt.Format, validator strfmt.Validator)

RegisterFormat registers a custom format validator

func (*ServiceOrderingV42API) RegisterProducer

func (o *ServiceOrderingV42API) RegisterProducer(mediaType string, producer runtime.Producer)

RegisterProducer allows you to add (or override) a producer for a media type.

func (*ServiceOrderingV42API) Serve

Serve creates a http handler to serve the API over HTTP can be used directly in http.ListenAndServe(":8000", api.Serve(nil))

func (*ServiceOrderingV42API) ServeErrorFor

func (o *ServiceOrderingV42API) ServeErrorFor(operationID string) func(http.ResponseWriter, *http.Request, error)

ServeErrorFor gets a error handler for a given operation id

func (*ServiceOrderingV42API) SetDefaultConsumes

func (o *ServiceOrderingV42API) SetDefaultConsumes(mediaType string)

SetDefaultConsumes returns the default consumes media type

func (*ServiceOrderingV42API) SetDefaultProduces

func (o *ServiceOrderingV42API) SetDefaultProduces(mediaType string)

SetDefaultProduces sets the default produces media type

func (*ServiceOrderingV42API) SetSpec

func (o *ServiceOrderingV42API) SetSpec(spec *loads.Document)

SetSpec sets a spec that will be served for the clients.

func (*ServiceOrderingV42API) UseRedoc

func (o *ServiceOrderingV42API) UseRedoc()

UseRedoc for documentation at /docs

func (*ServiceOrderingV42API) UseSwaggerUI

func (o *ServiceOrderingV42API) UseSwaggerUI()

UseSwaggerUI for documentation at /docs

func (*ServiceOrderingV42API) Validate

func (o *ServiceOrderingV42API) Validate() error

Validate validates the registrations in the ServiceOrderingV42API

Jump to